@@ -3,6 +3,7 @@ from .data_manager import DataManager
 
 # text processor
 from .text_processor import TextProcessor
+from .text_processors import DefaultTextProcessor
 
 # attacker
 from .attacker import Attacker
@@ -11,7 +12,7 @@ from . import attackers
 # classifier
 from .classifier import Classifier
 
-from .classifiers import PytorchClassifier, TensorflowClassifier
+from .classifiers import PytorchClassifier, TensorflowClassifier, HuggingfaceClassifier
 from . import classifiers
 
 # attack_eval
@@ -35,4 +36,6 @@ load = DataManager.load
 loadDataset = DataManager.loadDataset
 loadAttackAssist = DataManager.loadAttackAssist
 loadVictim = DataManager.loadVictim
-loadTProcess = DataManager.loadTProcess
\ No newline at end of file
+loadTProcess = DataManager.loadTProcess
+
+from .version import VERSION as __version__
\ No newline at end of file
