@@ -4,9 +4,12 @@ from .fd import FDAttacker
 from .hotflip import HotFlipAttacker
 from .textfooler import TextFoolerAttacker
 from .pwws import PWWSAttacker
-from .sea import SEAAttacker
+# from .sea import SEAAttacker
 from .uat import UATAttacker
 from .viper import VIPERAttacker
 from .deepwordbug import DeepWordBugAttacker
 from .gan import GANAttacker
 from .textbugger import TextBuggerAttacker
+from .pso import PSOAttacker
+from .bert_attack import BERTAttacker
+from .bae import BAEAttacker
