@@ -10,11 +10,11 @@ import os
 
 NAME = "TProcess.NLTKPerceptronPosTagger"
 
-URL = "https://thunlp.oss-cn-qingdao.aliyuncs.com/TAADToolbox/averaged_perceptron_tagger.pickle.zip"
+URL = "https://cdn.data.thunlp.org/TAADToolbox/averaged_perceptron_tagger.pickle.zip"
 DOWNLOAD = make_zip_downloader(URL, "averaged_perceptron_tagger.pickle")
 
 
 def LOAD(path):
     ret = __import__("nltk").tag.PerceptronTagger(load=False)
-    ret.load(os.path.join(path, "averaged_perceptron_tagger.pickle"))
+    ret.load("file:" + os.path.join(path, "averaged_perceptron_tagger.pickle"))
     return ret.tag
