@@ -9,10 +9,10 @@ import os
 
 NAME = "TProcess.NLTKSentTokenizer"
 
-URL = "https://thunlp.oss-cn-qingdao.aliyuncs.com/TAADToolbox/punkt.english.pickle.zip"
+URL = "https://cdn.data.thunlp.org/TAADToolbox/punkt.english.pickle.zip"
 DOWNLOAD = make_zip_downloader(URL, "english.pickle")
 
 
 def LOAD(path):
-    return __import__("nltk").data.load(os.path.join(path, "english.pickle")).tokenize
+    return __import__("nltk").data.load("file:" + os.path.join(path, "english.pickle")).tokenize
 
