@@ -9,14 +9,14 @@ from OpenAttack.utils import make_zip_downloader
 
 NAME = "TProcess.NLTKWordNet"
 
-URL = "https://thunlp.oss-cn-qingdao.aliyuncs.com/TAADToolbox/wordnet.zip"
+URL = "https://cdn.data.thunlp.org/TAADToolbox/wordnet.zip"
 DOWNLOAD = make_zip_downloader(URL)
 
-
-def LOAD(path):
-    wnc = __import__("nltk").corpus.WordNetCorpusReader(path, None)
-
-    def lemma(word, pos):
+class Lemmatizer:
+    def __init__(self, wnc):
+        self.__wnc = wnc
+    
+    def __call__(self, word, pos):
         pp = "n"
         if pos in ["a", "r", "n", "v", "s"]:
             pp = pos
@@ -33,8 +33,10 @@ def LOAD(path):
                 pp = None
         if pp is None:  # do not need lemmatization
             return word
-        lemmas = wnc._morphy(word, pp)
+        lemmas = self.__wnc._morphy(word, pp)
         return min(lemmas, key=len) if len(lemmas) > 0 else word
 
-    wnc.lemma = lemma
+def LOAD(path):
+    wnc = __import__("nltk").corpus.WordNetCorpusReader(path, None)
+    wnc.lemma = Lemmatizer(wnc)
     return wnc
