@@ -1,6 +1,7 @@
 """
 :type: function
 :Size: 21.164MB
+:Package Requirements: * **Java**
 
 Model files for Stanford NER tagger.
 `[page] <https://nlp.stanford.edu/software/CRF-NER.html>`__
@@ -10,7 +11,7 @@ import os
 
 NAME = "TProcess.StanfordNER"
 
-URL = "https://thunlp.oss-cn-qingdao.aliyuncs.com/TAADToolbox/stanford_ner_small.zip"
+URL = "https://cdn.data.thunlp.org/TAADToolbox/stanford_ner_small.zip"
 DOWNLOAD = make_zip_downloader(URL)
 
 
