@@ -1,6 +1,7 @@
 """
 :type: function
 :Size: 603.979MB
+:Package Requirements: * **Java**
 
 Model files for Stanford Parser.
 `[page] <https://nlp.stanford.edu/software/lex-parser.shtml>`__
@@ -10,7 +11,7 @@ import os
 
 NAME = "TProcess.StanfordParser"
 
-URL = "https://thunlp.oss-cn-qingdao.aliyuncs.com/TAADToolbox/stanford_parser_small.zip"
+URL = "https://cdn.data.thunlp.org/TAADToolbox/stanford_parser_small.zip"
 DOWNLOAD = make_zip_downloader(URL)
 
 
